@@ -2,7 +2,7 @@ from tempfile import mkdtemp
 
 from django.contrib import messages
 from edc_constants.constants import YES
-from edc_identifier.simple_identifier import convert_to_human_readable
+from edc_identifier.utils import convert_to_human_readable
 from edc_lab.model_mixins import RequisitionModelMixin
 from edc_lab.models.manifest.shipper import Shipper
 from edc_pdf_reports import Report
