@@ -16,7 +16,6 @@ from .base_requisition_view import BaseRequisitionView
 
 
 class RequisitionPrintActionsView(BaseRequisitionView):
-
     job_result_cls = JobResult
     requisition_report_cls = RequisitionReport
     requisition_labels_cls = RequisitionLabels
@@ -33,9 +32,6 @@ class RequisitionPrintActionsView(BaseRequisitionView):
         self.consignee = None
         super().__init__(**kwargs)
 
-    def get(self, request, *args, **kwargs):
-        return super().get(request, *args, **kwargs)
-
     def post(self, request, *args, **kwargs):
         response = None
         if self.selected_panel_names:
@@ -99,7 +95,7 @@ class RequisitionPrintActionsView(BaseRequisitionView):
                 consignee=self.consignee,
                 request=self.request,
             )
-            response = requisition_report.render()
+            response = requisition_report.render_to_response()
         else:
             messages.error(self.request, 'Nothing to do. No "verified" requisitions selected.')
             response = None
